@@ -1,9 +1,9 @@
 /*
- *  $Id: tailbox.c,v 1.81 2023/10/03 00:07:32 tom Exp $
+ *  $Id: tailbox.c,v 1.90 2026/01/01 19:21:18 tom Exp $
  *
  *  tailbox.c -- implements the tail box
  *
- *  Copyright 2000-2022,2023	Thomas E. Dickey
+ *  Copyright 2000-2025,2026	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -80,10 +80,51 @@ get_line(MY_OBJ * obj)
  * Print a new line of text.
  */
 static void
-print_line(MY_OBJ * obj, WINDOW *win, int row, int width)
+print_line(MY_OBJ * obj, WINDOW *win, int row, int limit)
 {
-    (void) wmove(win, row, 0);	/* move cursor to correct line */
-    dlg_print_nowrap(win, get_line(obj), width);
+    int y;
+    int x;
+    int i;
+
+    if (dialog_state.color_mode & coloredContent) {
+	bool save_colors = dialog_vars.colors;
+	const char *line = get_line(obj);
+	const int *cols = dlg_index_columns(line);
+	chtype my_attr = dialog_attr;
+	int first = 0;
+	int last = limit;
+
+	if (limit > getmaxx(obj->text))
+	    limit = getmaxx(obj->text);
+	--limit;		/* for the leading ' ' */
+
+#define ValidCol(n) ((n) <= limit && cols[(n)] >= 0)
+
+	x = 1;
+	for (i = 0; ValidCol(i) && cols[i] < obj->hscroll; ++i)
+	    first = i;
+
+	for (i = first; ValidCol(i) && ((cols[i] - cols[first]) < limit); ++i)
+	    last = i;
+
+	dialog_vars.colors = TRUE;
+	wmove(obj->text, row, x);
+	dlg_attrset(obj->text, my_attr);
+	dlg_print_line(obj->text, &my_attr, line + first,
+		       obj->hscroll + first,
+		       obj->hscroll + last, &x);
+	dialog_vars.colors = save_colors;
+    } else {
+	(void) wmove(win, row, 0);	/* move cursor to correct line */
+	dlg_print_nowrap(win, get_line(obj), limit);
+    }
+
+    getyx(obj->text, y, x);
+    if (y == row) {		/* Clear 'residue' of previous line */
+	for (i = 0; i <= limit - x; i++) {
+	    (void) waddch(obj->text, ' ');
+	}
+    }
 }
 
 /*
@@ -206,11 +247,11 @@ handle_input(DIALOG_CALLBACK * cb)
 }
 
 static bool
-valid_callback(DIALOG_CALLBACK * cb)
+valid_callback(const DIALOG_CALLBACK * cb)
 {
     bool valid = FALSE;
     DIALOG_CALLBACK *p;
-    for (p = dialog_state.getc_callbacks; p != 0; p = p->next) {
+    for (p = dialog_state.getc_callbacks; p != NULL; p = p->next) {
 	if (p == cb) {
 	    valid = TRUE;
 	    break;
@@ -322,7 +363,7 @@ dialog_tailbox(const char *title,
     int fkey;
     int x, y, result = DLG_EXIT_UNKNOWN, thigh;
     WINDOW *dialog, *text;
-    const char **buttons = 0;
+    const char **buttons = NULL;
     MY_OBJ *obj;
     FILE *fd;
     int min_width = 12;
@@ -381,7 +422,7 @@ dialog_tailbox(const char *title,
     obj->obj.input = fd;
     obj->obj.win = dialog;
     obj->obj.handle_getc = handle_my_getc;
-    obj->obj.handle_input = bg_task ? handle_input : 0;
+    obj->obj.handle_input = bg_task ? handle_input : NULL;
     obj->obj.keep_bg = bg_task && dialog_vars.cant_kill;
     obj->obj.bg_task = (bool) bg_task;
     obj->text = text;
